@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'pathspec/regexspec'
 
 class PathSpec
@@ -87,7 +89,7 @@ class PathSpec
                    end
 
         # Build regular expression from pattern.
-        regex = '^'
+        regex = +'^'
         need_slash = false
         regex_end = pattern_segs.size - 1
         pattern_segs.each_index do |i|
@@ -153,20 +155,19 @@ class PathSpec
     end
 
     def translate_segment_glob(pattern)
-      ''"
-    Translates the glob pattern to a regular expression. This is used in
-    the constructor to translate a path segment glob pattern to its
-    corresponding regular expression.
-
-    *pattern* (``str``) is the glob pattern.
-
-    Returns the regular expression (``str``).
-      "''
+      # Translates the glob pattern to a regular expression. This is used in
+      # the constructor to translate a path segment glob pattern to its
+      # corresponding regular expression.
+      #
+      # *pattern* (``str``) is the glob pattern.
+      #
+      # Returns the regular expression (``str``).
+      #
       # NOTE: This is derived from `fnmatch.translate()` and is similar to
       # the POSIX function `fnmatch()` with the `FNM_PATHNAME` flag set.
 
       escape = false
-      regex = ''
+      regex = +''
       i = 0
 
       while i < pattern.size
